@@ -5,14 +5,15 @@ use warnings;
 package Log::Any::Adapter::File;
 
 # ABSTRACT: Simple adapter for logging to files
-our $VERSION = '1.031'; # TRIAL
+our $VERSION = '1.033'; # TRIAL
 
 use Config;
 use Fcntl qw/:flock/;
 use IO::File;
 use Log::Any::Adapter::Util ();
 
-use base qw/Log::Any::Adapter::Base/;
+use Log::Any::Adapter::Base;
+our @ISA = qw/Log::Any::Adapter::Base/;
 
 my $HAS_FLOCK = $Config{d_flock} || $Config{d_fcntl_can_lock} || $Config{d_lockf};
 
@@ -32,7 +33,9 @@ sub init {
         $self->{log_level} = $trace_level;
     }
     my $file = $self->{file};
-    open( $self->{fh}, ">>", $file )
+    my $binmode ||= ':utf8';
+    $binmode = ":$binmode" unless substr($binmode,0,1) eq ':';
+    open( $self->{fh}, ">>$binmode", $file )
       or die "cannot open '$file' for append: $!";
     $self->{fh}->autoflush(1);
 }
@@ -73,7 +76,7 @@ Log::Any::Adapter::File - Simple adapter for logging to files
 
 =head1 VERSION
 
-version 1.031
+version 1.033
 
 =head1 SYNOPSIS
 
@@ -100,8 +103,19 @@ will be locked when writing.
 
 The C<log_level> attribute may be set to define a minimum level to log.
 
+The C<binmode> attribute may be set to define a PerlIO layer string to use
+when opening the file.  The default is C<:utf8>.
+
 Category is ignored.
 
+=head1 NAME
+
+Log::Any::Adapter::File - Simple adapter for logging to files
+
+=head1 VERSION
+
+version 1.033
+
 =head1 SEE ALSO
 
 L<Log::Any|Log::Any>, L<Log::Any::Adapter|Log::Any::Adapter>
@@ -127,4 +141,25 @@ This software is copyright (c) 2014 by Jonathan Swartz and David Golden.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Jonathan Swartz <swartz@pobox.com>
+
+=item *
+
+David Golden <dagolden@cpan.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2014 by Jonathan Swartz and David Golden.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
