@@ -5,11 +5,12 @@ use warnings;
 package Log::Any::Adapter::Stdout;
 
 # ABSTRACT: Simple adapter for logging to STDOUT
-our $VERSION = '1.031'; # TRIAL
+our $VERSION = '1.033'; # TRIAL
 
 use Log::Any::Adapter::Util ();
 
-use base qw/Log::Any::Adapter::Base/;
+use Log::Any::Adapter::Base;
+our @ISA = qw/Log::Any::Adapter::Base/;
 
 my $trace_level = Log::Any::Adapter::Util::numeric_level('trace');
 
@@ -58,7 +59,7 @@ Log::Any::Adapter::Stdout - Simple adapter for logging to STDOUT
 
 =head1 VERSION
 
-version 1.031
+version 1.033
 
 =head1 SYNOPSIS
 
@@ -81,6 +82,14 @@ with a newline appended. Category is ignored.
 
 The C<log_level> attribute may be set to define a minimum level to log.
 
+=head1 NAME
+
+Log::Any::Adapter::Stdout - Simple adapter for logging to STDOUT
+
+=head1 VERSION
+
+version 1.033
+
 =head1 SEE ALSO
 
 L<Log::Any|Log::Any>, L<Log::Any::Adapter|Log::Any::Adapter>
@@ -106,4 +115,25 @@ This software is copyright (c) 2014 by Jonathan Swartz and David Golden.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Jonathan Swartz <swartz@pobox.com>
+
+=item *
+
+David Golden <dagolden@cpan.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2014 by Jonathan Swartz and David Golden.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
