@@ -4,12 +4,13 @@ use warnings;
 
 package Log::Any::Adapter::Test;
 
-our $VERSION = '1.031'; # TRIAL
+our $VERSION = '1.033'; # TRIAL
 
 use Log::Any::Adapter::Util qw/dump_one_line/;
 use Test::Builder;
 
-use base qw/Log::Any::Adapter::Base/;
+use Log::Any::Adapter::Base;
+our @ISA = qw/Log::Any::Adapter::Base/;
 
 my $tb = Test::Builder->new();
 my @msgs;
@@ -74,6 +75,8 @@ sub clear {
 sub contains_ok {
     my ( $self, $regex, $test_name ) = @_;
 
+    local $Test::Builder::Level = $Test::Builder::Level + 1;
+
     $test_name ||= "log contains '$regex'";
     my $found =
       _first_index( sub { $_->{message} =~ /$regex/ }, @{ $self->msgs } );
@@ -83,14 +86,16 @@ sub contains_ok {
     }
     else {
         $tb->ok( 0, $test_name );
-        $tb->diag( "could not find message matching $regex; log contains: "
-              . $self->dump_one_line( $self->msgs ) );
+        $tb->diag( "could not find message matching $regex" );
+        _diag_msgs();
     }
 }
 
 sub category_contains_ok {
     my ( $self, $category, $regex, $test_name ) = @_;
 
+    local $Test::Builder::Level = $Test::Builder::Level + 1;
+
     $test_name ||= "log for $category contains '$regex'";
     my $found =
       _first_index(
@@ -102,21 +107,22 @@ sub category_contains_ok {
     }
     else {
         $tb->ok( 0, $test_name );
-        $tb->diag(
-            "could not find $category message matching $regex; log contains: "
-              . $self->dump_one_line( $self->msgs ) );
+        $tb->diag( "could not find $category message matching $regex" );
+        _diag_msgs();
     }
 }
 
 sub does_not_contain_ok {
     my ( $self, $regex, $test_name ) = @_;
 
+    local $Test::Builder::Level = $Test::Builder::Level + 1;
+
     $test_name ||= "log does not contain '$regex'";
     my $found =
       _first_index( sub { $_->{message} =~ /$regex/ }, @{ $self->msgs } );
     if ( $found != -1 ) {
         $tb->ok( 0, $test_name );
-        $tb->diag( "found message matching $regex: " . $self->msgs->[$found] );
+        $tb->diag( "found message matching $regex: " . $self->msgs->[$found]->{message} );
     }
     else {
         $tb->ok( 1, $test_name );
@@ -126,6 +132,8 @@ sub does_not_contain_ok {
 sub category_does_not_contain_ok {
     my ( $self, $category, $regex, $test_name ) = @_;
 
+    local $Test::Builder::Level = $Test::Builder::Level + 1;
+
     $test_name ||= "log for $category contains '$regex'";
     my $found =
       _first_index(
@@ -144,14 +152,16 @@ sub category_does_not_contain_ok {
 sub empty_ok {
     my ( $self, $test_name ) = @_;
 
+    local $Test::Builder::Level = $Test::Builder::Level + 1;
+
     $test_name ||= "log is empty";
     if ( !@{ $self->msgs } ) {
         $tb->ok( 1, $test_name );
     }
     else {
         $tb->ok( 0, $test_name );
-        $tb->diag( "log is not empty; contains "
-              . $self->dump_one_line( $self->msgs ) );
+        $tb->diag( "log is not empty" );
+        _diag_msgs();
         $self->clear();
     }
 }
@@ -159,6 +169,8 @@ sub empty_ok {
 sub contains_only_ok {
     my ( $self, $regex, $test_name ) = @_;
 
+    local $Test::Builder::Level = $Test::Builder::Level + 1;
+
     $test_name ||= "log contains only '$regex'";
     my $count = scalar( @{ $self->msgs } );
     if ( $count == 1 ) {
@@ -167,8 +179,18 @@ sub contains_only_ok {
     }
     else {
         $tb->ok( 0, $test_name );
-        $tb->diag( "log contains $count messages: "
-              . $self->dump_one_line( $self->msgs ) );
+        _diag_msgs();
+    }
+}
+
+sub _diag_msgs {
+    my $count = @msgs;
+    if ( ! $count ) {
+        $tb->diag("log contains no messages");
+    }
+    else {
+        $tb->diag("log contains $count message" . ( $count > 1 ? "s:" : ":"));
+        $tb->diag(dump_one_line($_)) for @msgs;
     }
 }
 
@@ -181,4 +203,5 @@ sub _first_index {
     return -1;
 }
 
+
 1;
