@@ -4,9 +4,10 @@ use warnings;
 
 package Log::Any::Proxy::Test;
 
-our $VERSION = '1.031'; # TRIAL
+our $VERSION = '1.033'; # TRIAL
 
-use base qw/Log::Any::Proxy/;
+use Log::Any::Proxy;
+our @ISA = qw/Log::Any::Proxy/;
 
 my @test_methods = qw(
   msgs
